# Daniel Kahn Gillmor

![Daniel Kahn Gillmor - Photo](//static.fsf.org/nosvn/libreplanet/speaker-pics/dkg.jpg)

Daniel Kahn Gillmor is a technologist with the ACLU's Speech, Privacy and Technology Project, and a free software developer. He's a Free Software Foundation member, a member of Debian, a contributor to a wide range of free software projects, and a participant in protocol development standards organizations like the IETF, with an eye toward preserving and improving civil liberties and civil rights through our shared infrastructure.

# Edward Snowden

![Edward Snowden - Photo](//static.fsf.org/nosvn/libreplanet/speaker-pics/snowden.jpg)

Edward Snowden is a former intelligence officer who served the CIA, NSA, and DIA for nearly a decade as a subject matter expert on technology and cybersecurity. In 2013, he revealed the NSA was unconstitutionally seizing the private records of billions of individuals who had not been suspected of any wrongdoing, resulting in the largest debate about reforms to US surveillance policy since 1978. Today, he works on methods of enforcing human rights through the application and development of new technologies. He joined the board of Freedom of the Press Foundation in February 2014.

## Michaela R. Brown, Mozilla

![Michaela R. Brown - Photo](//static.fsf.org/nosvn/libreplanet/speaker-pics/brown.jpg)

I'm a trans* Internet freedom fighter from the middle of nowhere (Gladwin, Michigan). I've volunteered with Mozilla since 2014, where I'm a technical speaker and digital rights evangelist.

## Marianne Corvellec, April

![Marianne Corvellec - Photo](//static.fsf.org/nosvn/libreplanet/speaker-pics/corvellec.jpg)

Marianne Corvellec has been a Free Software activist with April since 2011. April is an advocacy association which has been promoting and defending Free Software in France and Europe since 1996. Marianne's focus has been on legal and institutional issues.

## Richard Fontana

Richard Fontana is a lawyer at Red Hat. He leads support for Red Hat's engineering and research and development units and is Red Hat's lead counsel for legal issues relating to free software. Richard is also a board director of the Open Source Initiative.


## Molly Gott, LittleSis

Molly Gott is an organizer and researcher at LittleSis, where she focuses on building teams of activist-researchers doing power analysis research in their communities.  Previously, she organized in St. Louis with MORE, an economic and climate justice community organization. At MORE, she led the Power Behind the Police movement research team, which exposed the ties between St. Louis' corporate elite and the region's structural racism.

## Matt Lee, GNU Project

Matt Lee is a free software hacker, film maker and artist living in Austin, TX.

## Deb Nicholson, Open Invention Network

![Deb Nicholson - Photo](//static.fsf.org/nosvn/libreplanet/speaker-pics/nicholson.jpg)

Deb Nicholson wants to make the world a better place with technology and social justice for all. After many years of local political organizing, she became an enthusiastic free software activist. She is currently the Community Outreach Director at the Open Invention Network and the Community Manager at GNU MediaGoblin. She also serves on the board at Open Hatch, a.k.a. Free Software's Welcoming Committee.

## Alexandre Oliva, FSF Latin America

![Alexandre Oliva - Photo](//static.fsf.org/nosvn/libreplanet/speaker-pics/oliva.png)

FSF Latin America board member. GNU speaker. Free Software Evangelist. Maintainer of GNU Linux-libre, and co-maintainer of the GNU Compiler Collection, GNU binutils and GNU libc. GNU tools engineer at Red Hat Brasil.

## Eric Schultz

![Eric Schultz - Photo](//static.fsf.org/nosvn/libreplanet/speaker-pics/schultz.jpg)

Eric Schultz is an independent software engineer and open source consultant. Most recently he was the Community Manager at prpl Foundation with a particular focus on building the OpenWrt community. Prior to this, Eric worked as Developer Advocate at Outercurve Foundation where he managed and supported the foundation’s 25 open source projects. Eric has collaborated with employees from dozens of companies to create free and open source software that improves lives. He has a passion for the promise and reality of free software, with a focus on empowering individuals, particularly in marginalized groups, with more control over their everyday lives. Eric lives in Appleton, Wisconsin where outside of work he enjoys developing free software, watching the Green Bay Packers and Milwaukee Bucks, and tweeting about technology, cute animals, politics and sports.

## Andrew Seeder, Dudley Street Neighborhood Initiative

![Andrew Seeder - Photo](//static.fsf.org/nosvn/libreplanet/speaker-pics/seeder.jpg)

Andrew Seeder is the Data Systems Manager at the Dudley Street Neighborhood Initiative in Roxbury, Boston. He is also a consultant for the Smart Chicago Collaborative, sits on the IT Working Group for Boston Ujima, and is a member of the young professionals committee for YMCA's Training, Inc. He helps organize cryptoparties and works with friends on the Boston Meshnet project. Tweet him at @ahseeder.

## David Thompson, GNU Guix

David Thompson is an FSF alumnus and Guile Scheme hacker. David works on system deployment tools for Guix, develops a functional reactive game engine called Sly (it's cool, you should check it out!), and is frequently found nose-deep in his copy of SICP. He lives in the Boston area.

## Stefano Zacchiroli, Debian, OSI, IRILL

![Stefano Zacchiroli - Photo](//static.fsf.org/nosvn/libreplanet/speaker-pics/zacchiroli.jpg)

Stefano Zacchiroli is Associate Professor of Computer Science at University Paris Diderot. His research interests span formal methods and their applications to improve software quality and user experience in the context of Free Software distributions. He has been an official member of the Debian Project since 2001, taking care of many tasks from package maintenance to distribution-wide Quality Assurance. He has been elected to serve as Debian Project Leader for 3 terms in a row, over the period 2010-2013. He is a Board Director of the Open Source Initiative (OSI). He is a recipient of the 2015 O'Reilly Open Source Award.
